/*
 *	July 1995 - Mathijs Maassen
 *	Changes:
 *		13 Aug 1995 - Take nr_days from EPURMESS.INI.
 *		              First release to PA3AES@PI8WFL
 */

#include <stdio.h>
#include <time.h>
#include <string.h>
#include <stdlib.h>
#include "fbb.h"

#define VERSTR	"CHKFWD v1.0 - Mathijs Maassen <pe1ntp@pi8daz.#twe.nld.eu>\n"

#define SECS_PER_DAY 86400L

char dirmes_sys[128], mail_in[128], sysop[40];
int nr_days = 0;

void read_epurmess(void)
{
	FILE *fp;
	char line[256];
	int line_num = 0;

	if ((fp = fopen("epurmess.ini", "r")) == NULL) {
		perror("Can't open EPURMESS.INI");
		exit(1);
	}

	while (line_num != 21 && fgets(line, sizeof(line), fp) != NULL) {
		if (line[0] == '#')
			continue;
		if (++line_num == 21) {
			sscanf(line, "%d", &nr_days);
			nr_days--;
		}
	}
	fclose(fp);
}

void read_init_srv(void)
{
	FILE *fp;
	char line[128];
	int line_num = 0;

	if ((fp = fopen("init.srv", "r")) == NULL) {
		perror("Can't open INIT.SRV");
		exit(1);
	}

	while (line_num != 14 && fgets(line, sizeof(line), fp) != NULL) {
		if (line[0] == '#')
			continue;
		line[strlen(line) - 1] = '\0';
		switch (++line_num) {
		case 5:
			strcpy(dirmes_sys, line);
			strcat(dirmes_sys, "dirmes.sys");
			break;
		case 12:
			strcpy(sysop, line);
			break;
		case 14:
			strcpy(mail_in, line);
			break;
		}
	}
	fclose(fp);
}

int main(int argc, char **argv)
{
	FILE *fp, *mail_infp;
	bullist data;
	int i, started = 0;
	time_t now;
	char time_str[15];

	puts(VERSTR);

	if (argc == 2) {
		if (sscanf(argv[1], "%d", &nr_days) != 1) {
			puts("Usage: CHKFWD [nr_days]\n\n"
			"  [nr_days] is the number of days after which a warning message is sent to the sysop.\n"
			"  If [nr_days] is not present the value is taken from line 21 of EPURMESS.INI.");
		}
	}
	else
		read_epurmess();

	printf("Warning sent after %d days\n", nr_days);

	read_init_srv();

	if ((fp = fopen(dirmes_sys, "rb")) == NULL) {
		perror("Error opening DIRMES.SYS");
		return (1);
	}

	tzset();
	time(&now);

	while (fread(&data, sizeof(data), 1, fp) == 1) {
		if (data.type != 'P' || data.status != 'N' || !data.bbsv[0] || now - data.date < nr_days * SECS_PER_DAY)
			continue;
		for (i = 0; i < 10 && data.fbbs[i] == 0; i++);
		if (i != 10)
			continue;
		strftime(time_str, sizeof(time_str), "%y%m%d/%H%M", localtime(&data.date));
		if (!started) {
			started = 1;
			if ((mail_infp = fopen(mail_in, "a")) == NULL) {
				perror(mail_in);
				exit(1);
			}
			fprintf(mail_infp, "#\nSP %s < SYSTEM\n", sysop);
			fputs("*** INCORRECT ROUTING ***\n Msg#  TS  Size To    @BBS    From   Date        Subject\n", mail_infp);
		}
		fprintf(mail_infp, "%6ld P%c %5ld %-6s@%-6.6s %-6s %s %.30s\n", data.numero, data.status, data.taille, data.desti, data.bbsv, data.exped, time_str, data.titre);
	}

	if (started) {
		fputs("/EX\n", mail_infp);
		fclose(mail_infp);
	}

	fclose(fp);
	puts("Done.");
	return (0);
}
